// Written by TeTeT
// sample mission for radio init on the fly

// some evil global, following Columdrums example
uns_radios = [];
publicVariable "uns_radios";

/**
 * Create a radio object and tie it to unit
 **/
uns_radio2_fnc_createRadio = {
	params ["_unit"];
	private _radio = createVehicle ["uns_radio2_obj", getPos _unit, [], 0, "CAN_COLLIDE"];
	_radio allowDamage false;
	_unit setVariable ["uns_radio", _radio, true];
	_radio setVariable ["uns_radioOwner", _unit, true];
	_radio;
};

/**
 * attach radio to unit
 **/
uns_radio2_fnc_attachRadio = {
	params ["_unit"];
	private _radio = _unit getVariable ["uns_radio", ObjNull];
	detach _radio;
	_radio setPos (getPos _unit);
	_radio attachTo [_unit];
	_radio;
};

/**
 * detach radio from unit
 **/
uns_radio2_fnc_detachRadio = {
	params ["_unit"];
	private _radio = _unit getVariable ["uns_radio", ObjNull];
	detach _radio;
	_radio setPos [0,0,-1000];
	_radio;
};

/**
 * Check if unit has radio or not
 **/
uns_radio2_fnc_hasRadio = {
	params [["_unit", ObjNull]];
	private _ret = false;
	private _assignedItems = assignedItems _unit;
	if ("uns_ItemRadio_transistor_1" in _assignedItems or
		"uns_ItemRadio_transistor_2" in _assignedItems or
		"UNS_ItemRadio_PRC_25" in _assignedItems or
		"UNS_ItemRadio_PRC_90" in _assignedItems or
		"UNS_ItemRadio_T_884" in _assignedItems) then {
		_ret = true;
	};

	if (!_ret) then {
		private _itemCargo = itemCargo _unit;
		if ("uns_ItemRadio_transistor_1" in _itemCargo or
			"uns_ItemRadio_transistor_2" in _itemCargo or
			"UNS_ItemRadio_PRC_25" in _itemCargo or
			"UNS_ItemRadio_PRC_90" in _itemCargo or
			"UNS_ItemRadio_T_884" in _itemCargo) then {
			_ret = true;
		};
	};
	_ret;
};

/**
 * Playback radio sound
 **/
uns_radio2_fnc_playback = {
	params [["_radio", ObjNull]];
	if (isNull _radio) exitWith {};

	private _radioType = _radio getVariable ["_radioType", "WestGeneric"];
	private _channel = _radio getVariable ["_radioChannel", 2];

	// Eventually needs to be parsed from config
	private _eastGround = 48;
	private _eastAir = 0;
	private _eastGeneric = 0;

	private _westGround = 17;
	private _westAir = 14;
	private _westGeneric = 85;

	private _trackNumbers = 0;
	private _trackSide = "West";
	if (_radioType isEqualTo "WestGeneric") then {
		_trackNumbers = _westGeneric;
		_trackSide = "West";
	};
	if (_radioType isEqualTo "West" and _channel isEqualTo 0) then {
		_trackNumbers = _westGround;
		_trackSide = "West";
	};
	if (_radioType isEqualTo "West" and _channel isEqualTo 1) then {
		_trackNumbers = _westAir;
		_trackSide = "West";
	};
	if (_radioType isEqualTo "West" and _channel isEqualTo 2) then {
		_trackNumbers = _westGeneric;
		_trackSide = "West";
	};
	if (_radioType isEqualTo "East" and _channel isEqualTo 0) then {
		_trackNumbers = _eastGround;
		_trackSide = "East";
	};

	if (_trackNumbers isEqualTo 0) exitWith { diag_log "no uns_radio2 tracks available"; };

	while {alive _radio} do {
		// draw with putting back, should be draw without putting back eventually
		private _trackIndex = floor(random(_trackNumbers));
		private _nextTrack = format ["uns_radio_%1_chan%2_track%3", _trackSide, _channel, _trackIndex];
		systemChat format ["Playing %1 now", _nextTrack];
		[_radio, _nextTrack] call uns_mbox_fnc_remoteSay3D;
		private _duration = getNumber(ConfigFile >> "CfgSounds" >> _nextTrack >> "duration");
		sleep _duration;
		// short delay between tracks
		sleep 0.1;
	};
};

/**
 * Legacy function, for compatibility with UI
 **/
uns_radio_FNC_Radio_Toggle_ONOFF = {
	params [["_unit", ObjNull]];
	private _radio = _unit getVariable ["uns_radio", ObjNull];
	private _radioOn = _unit getVariable ['uns_radioOn', false];
	if (_radioOn) then {
		 [_unit] call uns_radio2_fnc_detachRadio;
		 _unit setVariable ['uns_radioOn', false, true];
	} else {
		 [_unit] call uns_radio2_fnc_attachRadio;
		 _unit setVariable ['uns_radioOn', true, true];
	};
};

/**
 * Legacy function, for compatibility with UI
 **/
uns_radio_FNC_Radio_SelectChannel = {
	params [["_unit", ObjNull]];
	[_unit] spawn {
		params [["_unit", ObjNull]];
		private _radio = _unit getVariable ["uns_radio", ObjNull];
		private _radioChannel = _radio getVariable "_radioChannel";
		private _radioType = _radio getVariable "_radioType";

		// only one channel supported on transistor radios for now
		if (_radioType isEqualTo "WestGeneric") exitWith {}; 
		// rotate through available channels
		_radioChannel = (_radioChannel + 1) mod 3; 

		systemChat format ["Trying to switch to '%1'", _radioChannel];
		deleteVehicle _radio;
		_radio = [_unit] call uns_radio2_fnc_createRadio;
		_radio setVariable ["_radioType", _radioType, true];
		_radio setVariable ["_radioChannel", _radioChannel, true];
		[_radio] spawn uns_radio2_fnc_playback;
		[_unit] call uns_radio2_fnc_attachRadio;
		_unit setVariable ['uns_radioOn', true, true];
	};
};

/**
 * Initialize radio with addAction and variables
 **/
uns_radioInit = {
	params [["_radioUnit", ObjNull], ["_radioType", "Civ"]];
	if (isNull _radioUnit) exitWith { false; };
	private _radio = [_radioUnit] call uns_radio2_fnc_createRadio;
	_radio setVariable ["_radioType", _radioType, true];
	_radio setVariable ["_radioChannel", 2, true];
	[_radioUnit] call uns_radio2_fnc_detachRadio;
	// [_radio, "UNS_RADIO_WEST_CHAN0_TRACK0"] call uns_mbox_fnc_remoteSay3D;
	[_radio] spawn uns_radio2_fnc_playback;
	_radioUnit setVariable ['uns_radioOn', false, true];
	_radioUnit addAction [
		"Radio ("+ str typeOf _radioUnit + ")",
		"uns_radio_owner = _this select 0; createDialog 'uns_radio_MainDiag_us';",
		[],
		1,
		false,
		true,
		"",
		"[_target] call uns_radio2_fnc_hasRadio;"
	];
	_radioUnit setVariable ["uns_radioInit", true, true];
};


[] spawn {
	sleep 15;
	private _grp = createGroup west;

	"uns_men_US_SOG_11" createUnit [getPos player, _grp];	
	(leader _grp) addItem "uns_ItemRadio_transistor_1";
	(leader _grp) assignItem "uns_ItemRadio_transistor_1";
};

[] spawn {
	while {true} do {
		private _unitz = allUnits;
		{
			private _unit = _x;
			private _radioType = "";
			private _assignedItems = assignedItems _unit;
			if ("uns_ItemRadio_transistor_1" in _assignedItems or
				"uns_ItemRadio_transistor_2" in _assignedItems or
				"UNS_ItemRadio_PRC_25" in _assignedItems or
				"UNS_ItemRadio_PRC_90" in _assignedItems or
				"UNS_ItemRadio_T_884" in _assignedItems) then {
				if ("uns_ItemRadio_transistor_1" in _assignedItems or
					"uns_ItemRadio_transistor_2" in _assignedItems) then {
					_radioType = "WestGeneric";
				};
				if ("UNS_ItemRadio_PRC_25" in _assignedItems or
					"UNS_ItemRadio_PRC_90" in _assignedItems) then {
					_radioType = "West";
				};
				if ("UNS_ItemRadio_T_884" in _assignedItems) then {
					_radioType = "East";
				};
				uns_radios pushBackUnique [_unit, _radioType];
			};
		} forEach _unitz;
		private _vehs = vehicles;
		{
			private _veh = _x;
			private _radioType = "";
			private _itemCargo = itemCargo _x;
			if ("uns_ItemRadio_transistor_1" in _itemCargo or
				"uns_ItemRadio_transistor_2" in _itemCargo or
				"UNS_ItemRadio_PRC_25" in _itemCargo or
				"UNS_ItemRadio_PRC_90" in _itemCargo or
				"UNS_ItemRadio_T_884" in _itemCargo) then {
				if ("uns_ItemRadio_transistor_1" in _itemCargo or
					"uns_ItemRadio_transistor_2" in _itemCargo) then {
					_radioType = "WestGeneric";
				};
				if ("UNS_ItemRadio_PRC_25" in _itemCargo or
					"UNS_ItemRadio_PRC_90" in _itemCargo) then {
					_radioType = "West";
				};
				if ("UNS_ItemRadio_T_884" in _itemCargo) then {
					_radioType = "East";
				};
				uns_radios pushBackUnique [_veh, _radioType];
			};
		} forEach _vehs;
		{
			private _radioUnit = _x select 0;
			private _radioType = _x select 1;

			if (!(_radioUnit getVariable ["uns_radioInit", false])) then {
				[_radioUnit, _radioType] call uns_radioInit;
			};
		} forEach uns_radios;
		sleep 1;
	};
};

